@@ -37,6 +37,9 @@ class Label(Framework.TestCase):
         self.assertEqual(self.label.name, "Bug")
         self.assertEqual(self.label.url, "https://api.github.com/repos/jacquev6/PyGithub/labels/Bug")
 
+        # test __repr__() based on this attributes
+        self.assertEqual(self.label.__repr__(), 'Label(name="Bug")')
+
     def testEdit(self):
         self.label.edit("LabelEditedByPyGithub", "0000ff")
         self.assertEqual(self.label.color, "0000ff")
