@@ -42,3 +42,6 @@ class PullRequestFile(Framework.TestCase):
         self.assertEqual(self.file.raw_url, "https://github.com/jacquev6/PyGithub/raw/8a4f306d4b223682dd19410d4a9150636ebe4206/codegen/templates/GithubObject.py")
         self.assertEqual(self.file.sha, "8a4f306d4b223682dd19410d4a9150636ebe4206")
         self.assertEqual(self.file.status, "modified")
+
+        # test __repr__() based on this attributes
+        self.assertEqual(self.file.__repr__(), 'File(sha="8a4f306d4b223682dd19410d4a9150636ebe4206", filename="codegen/templates/GithubObject.py")')
